aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xinstaller/install-clangd.sh28
1 files changed, 22 insertions, 6 deletions
diff --git a/installer/install-clangd.sh b/installer/install-clangd.sh
index 3d1cfd0..278792f 100755
--- a/installer/install-clangd.sh
+++ b/installer/install-clangd.sh
@@ -13,12 +13,28 @@ case $os in
;;
esac
-# Check Ubuntu version
-ubuntu_version=$(lsb_release -a 2>&1 | grep 'Release' | awk '{print $2}')
-
-case $ubuntu_version in
- 14.04|16.04|18.04)
- platform="linux-gnu-ubuntu-$ubuntu_version"
+distributor_id=$(lsb_release -a 2>&1 | grep 'Distributor ID' | awk '{print $3}')
+case $distributor_id in
+ # Check Ubuntu version
+ Ubuntu)
+ ubuntu_version=$(lsb_release -a 2>&1 | grep 'Release' | awk '{print $2}')
+ case $ubuntu_version in
+ 14.04|16.04|18.04)
+ platform="linux-gnu-ubuntu-$ubuntu_version"
+ ;;
+ esac
+ ;;
+ # Check LinuxMint version
+ LinuxMint)
+ linuxmint_version=$(lsb_release -a 2>&1 | grep 'Release' | awk '{print $2}')
+ case $linuxmint_version in
+ 19|19.1|19.2|19.3)
+ platform="linux-gnu-ubuntu-18.04"
+ ;;
+ 18|18.1|18.2|18.3)
+ platform="linux-gnu-ubuntu-16.04"
+ ;;
+ esac
;;
esac